@@ -1,23 +1,8 @@
-﻿/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logViewExport.h"
 
@@ -33,7 +18,7 @@
 #include <KMessageBox>
 #include <QPrintPreviewDialog>
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "logLine.h"
 #include "logViewWidget.h"
@@ -53,7 +38,7 @@ LogViewExport::~LogViewExport()
 
 void LogViewExport::sendMail()
 {
-    logDebug() << "Exporting to mail...";
+    qCDebug(KSYSTEMLOG) << "Exporting to mail...";
 
     QString body(i18n("Here are my logs:\n"));
 
@@ -133,7 +118,7 @@ void LogViewExport::print(QPrinter *printer)
 
 void LogViewExport::printSelection()
 {
-    logDebug() << "Printing selection...";
+    qCDebug(KSYSTEMLOG) << "Printing selection...";
 
     QPrinter printer;
 
@@ -157,7 +142,7 @@ void LogViewExport::printSelection()
 
 void LogViewExport::printPreview()
 {
-    logDebug() << "Printing selection...";
+    qCDebug(KSYSTEMLOG) << "Printing selection...";
 
     auto dialog = new QPrintPreviewDialog(mParent);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
@@ -172,7 +157,7 @@ void LogViewExport::printPreview()
 
 void LogViewExport::printPageNumber(QPainter &painter, QRect &printView, int movement, int page, int margin)
 {
-    logDebug() << "Printing page number...";
+    qCDebug(KSYSTEMLOG) << "Printing page number...";
 
     painter.translate(0, -movement);
     printView.moveTo(QPoint(margin, printView.height() * page + margin));
@@ -184,7 +169,7 @@ void LogViewExport::printPageNumber(QPainter &painter, QRect &printView, int mov
 
 void LogViewExport::copyToClipboard()
 {
-    logDebug() << "Copying to clipboard...";
+    qCDebug(KSYSTEMLOG) << "Copying to clipboard...";
 
     int nbCopied = 0;
     QString text;
@@ -212,12 +197,12 @@ void LogViewExport::copyToClipboard()
         Q_EMIT statusBarChanged(i18np("1 log line copied to clipboard.", "%1 log lines copied to clipboard.", nbCopied));
     }
 
-    logDebug() << "Copied " << nbCopied << " log lines";
+    qCDebug(KSYSTEMLOG) << "Copied " << nbCopied << " log lines";
 }
 
 void LogViewExport::fileSave()
 {
-    logDebug() << "Saving to a file...";
+    qCDebug(KSYSTEMLOG) << "Saving to a file...";
 
     QTreeWidgetItemIterator it(mLogViewWidget, QTreeWidgetItemIterator::Selected);
 
